global lambda rmin_kappa phi r_kappa

% Routine to determine the effective number of charges per unit length for a polyion in excess monovalent salt.
% The theory is covered in section 3.3.1 of the book. 
% We solve nabla^2 phi = sinh phi using scaled coordinates kappa*r.
% Give initial guess rstar*kappa, usually 1 or 2 will do.


c_salt_mol                  =   input('salt concentration in mol/l     : ');
bare_d                      =   input('bare polyion diameter in nm     : ');
rstar_kappa_guess           =   input('initial guess rstar*kappa       : ');

% Constants
l_B                         =   0.71;                                   % Bjerrum length at 298 K in nm for water
N_A                         =   6.022045e-1;                            % Avogadro number (modified magnitude, due to nm scale)
A                           =   0.171; 									% Distance between monomers in nm (B-form DNA)

% System parameters 
lambda                      =   l_B / A                                % Charge density parameter (eq. 3.11)
rho_s                       =   c_salt_mol * N_A                       % Salt ion density
kappa                       =   sqrt(8 * pi * l_B * rho_s)             % 1/kappa : Debye screening length (eqn. A.105)
rmin_kappa                  =   (bare_d / 2) * kappa				

% Finding rstar*kappa
% Find explanation in rstarfinder.m
rstar_kappa                 =   fzero('rstar_finder', rstar_kappa_guess)
nu_eff                      =   1 / (2 * l_B * besselk(0, rstar_kappa))

% Plot the numerical solution of the nonlinear PB equation
plot(r_kappa, phi(:,2));

xlabel('kappa * r')
ylabel('reduced potential')
hold

% Plot Debye-Huckel approximation
plot(r_kappa, 2 * l_B * nu_eff * besselk(0, r_kappa), '--')
hold